@@ -124,7 +124,7 @@ class MetadataHandler:
 class PredictionTypeHandler:
     name: str
     labels: List[str]
-    channel_dim: int
+    channel_dim: Optional[int] = -1
 
 
 @dataclass
