@@ -63,7 +63,7 @@ class CustomLayerInstance:
 class PredictionTypeInstance:
     name: str
     labels: List[str]
-    channel_dim: int
+    channel_dim: Optional[int] = -1
 
 
 @dataclass
